@@ -22,13 +22,17 @@ def addCatalogIndexes(site, logger):
     wanted = (("getAssignees", "KeywordIndex"),
               ("getBookingDate", "DateIndex"),
               ("getBillableProject", "FieldIndex"),
+              ("getEndDate", "DateIndex"),
              )
-
+    indexables = []
     for name, meta_type in wanted:
         if name not in indexes:
             catalog.addIndex(name, meta_type)
+            indexables.append(name)
             logger.info("Added %s for field %s.", meta_type, name)
-
+    if len(indexables) > 0:
+        logger.info("Indexing new indexes %s.", ', '.join(indexables))
+        catalog.manage_reindexIndex(ids=indexables)
 
 def configureKupu(portal, logger):
     """In Plone 3.0 / kupu 1.4 we can actually use a kupu.xml file
