@@ -9,82 +9,28 @@ class testWorkflow(eXtremeManagementTestCase):
     """
 
     def afterSetUp(self):
-        self.catalog = self.portal.portal_catalog
         self.workflow = self.portal.portal_workflow
-        self.membership = self.portal.portal_membership
-        self.default_user = default_user
 
-        self.membership.addMember('member', 'secret', ['Member'], [])
-        self.membership.addMember('reviewer', 'secret', ['Reviewer'], [])
-        self.membership.addMember('manager', 'secret', ['Manager'], [])
-        self.membership.addMember('employee', 'secret', ['Employee'], [])
-        self.membership.addMember('customer', 'secret', ['Customer'], [])
-
-        #self.login('initial')
-        self.login('manager')
-        # Create a projectfolder in the portal root
-        self.portal.invokeFactory('Folder', id='projects')
-        self.projects = self.folder.projects
-
-        self.projects.invokeFactory('Project', id='project')
-        self.project = self.projects.project
-        self.project.manage_addLocalRoles('customer', ['Customer'])
-
-        self.project.invokeFactory('Offer', id='offer')
+        self.project = self.portal.project
         self.offer = self.project.offer
-
-        self.project.invokeFactory('Iteration', id='iteration')
         self.iteration = self.project.iteration
-
-        # Create Story in iteration
-        self.iteration.invokeFactory('Story', id='story')
         self.story = self.iteration.story
-
-        # Create Story directly in project. At the moment this is
-        # allowed, but this may change in the future.
-        self.project.invokeFactory('Story', id='projectstory')
-        self.projectstory = self.project.projectstory
-
-        self.login('employee')
-        self.assertEqual(self.story.isEstimated(), False)
-        self.story.update(roughEstimate=4.5)
-        self.assertEqual(self.story.isEstimated(), True)
-        self.tryAllowedTransition(self.story, 'story',
-                                  'draft', 'estimate', 'estimated')
-
-        # Get a startable task
-        self.story.invokeFactory('Task', id='task')
         self.task = self.story.task
-        self.task.update(assignees=('employee', ))
-        self.task.update(hours=1)
-        self.assertEqual(self.task.startable(), True)
-
-        self.tryAllowedTransition(self.story, 'story',
-                                  'estimated', 'retract', 'draft')
-
-        self.task.invokeFactory('Booking', id='booking')
         self.booking = self.task.booking
-        self.main_objects = [self.portal, self.projects, self.project,
-                             self.iteration, self.story, self.task,
-                             self.booking]
-        self.logout()
-        self.login(self.default_user)
 
     def test_initial_states(self):
         """Test if the initial states for the CTs are what we expect
         them to be.
         """
 
-        self.assertEqual(
-            self.workflow.getInfoFor(self.projects, 'review_state'), 'private')
         self.assertEqual(
             self.workflow.getInfoFor(self.project, 'review_state'), 'private')
         self.assertEqual(
             self.workflow.getInfoFor(self.iteration, 'review_state'), 'new')
+        # Story has been transtioned already.  Let's make a new one.
+        self.iteration.invokeFactory('Story', id='story2')
         self.assertEqual(
-            self.workflow.getInfoFor(self.story, 'review_state'), 'draft')
-        self.assertEqual(
-            self.workflow.getInfoFor(self.projectstory, 'review_state'),
+            self.workflow.getInfoFor(self.iteration.story2, 'review_state'),
             'draft')
         self.assertEqual(
             self.workflow.getInfoFor(self.task, 'review_state'), 'open')
@@ -155,9 +101,6 @@ class testWorkflow(eXtremeManagementTestCase):
         """
         # Manager can do all transitions on an iteration:
         self.login('manager')
-        self.assertEqual(self.iteration.startable(), False)
-        self.tryAllowedTransition(self.story, 'story',
-                                  'draft', 'estimate', 'estimated')
         self.assertEqual(self.iteration.startable(), True)
         self.assertEqual(self.story.isEstimated(), True)
         self.assertEqual(self.story.startable(), True)
@@ -165,14 +108,12 @@ class testWorkflow(eXtremeManagementTestCase):
                                   'new', 'start', 'in-progress')
         self.assertEqual(self.workflow.getInfoFor(self.story, 'review_state'),
                          'in-progress')
-        self.assertEqual(self.iteration.completable(), False)
         self.assertEqual(self.story.completable(), False)
         self.tryAllowedTransition(self.task, 'task',
                                   'to-do', 'complete', 'completed')
         # This _should_ have automatically set the Story and the
         # Iteration to completed.
         self.assertEqual(self.story.completable(), True)
-        self.assertEqual(self.iteration.completable(), True)
         self.assertEqual(self.workflow.getInfoFor(self.story, 'review_state'),
                          'completed')
         self.assertEqual(
@@ -222,16 +163,14 @@ class testWorkflow(eXtremeManagementTestCase):
         """Test transitions of the Story Content Type as Manager.
         """
         self.setRoles(['Manager'])
-        # draft -> pending -> draft
+        # Return to initial state:
         self.tryAllowedTransition(self.story, 'story',
-                                  'draft', 'submit', 'pending')
+                                  'estimated', 'retract', 'draft')
+        # There is no need for a manager to set the story to pending
+        self.tryForbiddenTransition(self.story, 'draft', 'submit')
+        # draft -> estimated -> draft
         self.tryAllowedTransition(self.story, 'story',
-                                  'pending', 'retract', 'draft')
-        # draft -> pending -> estimated -> draft
-        self.tryAllowedTransition(self.story, 'story',
-                                  'draft', 'submit', 'pending')
-        self.tryAllowedTransition(self.story, 'story',
-                                  'pending', 'estimate', 'estimated')
+                                  'draft', 'estimate', 'estimated')
         self.tryAllowedTransition(self.story, 'story',
                                   'estimated', 'retract', 'draft')
         self.tryFullStoryRoute()
@@ -239,17 +178,23 @@ class testWorkflow(eXtremeManagementTestCase):
     def test_story_transitions_employee(self):
         """Test transitions of the Story Content Type as Employee.
         """
+        # Return to initial state:
+        self.tryAllowedTransition(self.story, 'story',
+                                  'estimated', 'retract', 'draft')
         self.setRoles(['Employee'])
         self.tryFullStoryRoute()
 
     def test_story_transitions_customer(self):
         """Test transitions of the Story Content Type as Customer.
         """
+        # Return to initial state:
+        self.tryAllowedTransition(self.story, 'story',
+                                  'estimated', 'retract', 'draft')
         self.setRoles(['Manager'])
         self.tryAllowedTransition(self.project, 'project',
                                   'private', 'activate', 'active')
-        self.setRoles(['Member'])
-        self.project.manage_addLocalRoles(self.default_user, ['Customer'])
+        self.login('customer')
+
         # draft -> pending -> draft
         self.tryAllowedTransition(self.story, 'story',
                                   'draft', 'submit', 'pending')
@@ -258,10 +203,10 @@ class testWorkflow(eXtremeManagementTestCase):
         # draft -> pending -> estimated -> draft
         self.tryAllowedTransition(self.story, 'story',
                                   'draft', 'submit', 'pending')
-        self.setRoles(['Employee'])
+        self.login('employee')
         self.tryAllowedTransition(self.story, 'story',
                                   'pending', 'estimate', 'estimated')
-        self.setRoles(['Member'])
+        self.login('customer')
         self.tryForbiddenTransition(self.story, 'estimated', 'activate')
         self.tryAllowedTransition(self.story, 'story',
                                   'estimated', 'retract', 'draft')
@@ -373,7 +318,8 @@ class testWorkflow(eXtremeManagementTestCase):
         self.workflow.doActionFor(ctObject, workflowTransition)
         self.assertEqual(self.workflow.getInfoFor(ctObject, 'review_state'),
                          newState)
-        self.failUnless(self.catalog(id=ctId, review_state=newState))
+        catalog = self.portal.portal_catalog
+        self.failUnless(catalog(id=ctId, review_state=newState))
 
     def twoStepTransition(self, ctObject, ctId, originalState,
                           workflowTransition,
